@@ -8,7 +8,7 @@ require DBI;
 no warnings qw/once/;
 
 BEGIN {
- $DBD::Neo4p::VERSION = '0.2000';
+ $DBD::Neo4p::VERSION = '0.2001';
 }
 
 our $err = 0;               # holds error code   for DBI::err
@@ -64,7 +64,6 @@ sub connect($$;$$$) {
       $key = "${prefix}_$key" unless $key =~ /^${prefix}_/;
       $dbh->STORE($key, $value);
     }
-    $DB::single=1;
   my $db = delete $rhAttr->{"${prefix}_database"} || delete $rhAttr->{"${prefix}_db"} || $dbh->{neo_db};
     my $host = $dbh->FETCH("${prefix}_host") || 'localhost';
     my $port = $dbh->FETCH("${prefix}_port") || 7474;
@@ -128,7 +127,8 @@ sub prepare {
 
 # cypher query parameters are given as tokens surrounded by curly braces:
 # crude count:
-    my @parms = $sStmt =~ /\{\s*([^}[:space:]]*)\s*\}/g;
+    my @parms = $sStmt =~ m/(?:{\s*([^}:[:space:]]*)\s*})|(?:[\$]([[:alnum:]_]+))/g;
+    @parms = map { $_ ? $_ : () } @parms; # squish undefs
     $sth->STORE('NUM_OF_PARAMS', scalar @parms);
     $sth->{"${prefix}_param_names"} = \@parms;
     $sth->{"${prefix}_param_values"} = [];
